@@ -225,8 +225,8 @@ class GSPDataSource(ImageDataSource):
         if total_gsp_nan_count == 0:
 
             # get random GSP metadata
-            indexes = list(
-                self.rng.integers(low=0, high=len(self.metadata), size=len(t0_datetimes_utc))
+            indexes = sorted(
+                list(self.rng.integers(low=0, high=len(self.metadata), size=len(t0_datetimes_utc)))
             )
             metadata = self.metadata.iloc[indexes]
 
