@@ -148,7 +148,7 @@ class ManagerLive(ManagerBase):
 
         return locations
 
-    def create_batches(self) -> None:
+    def create_batches(self, use_async: Optional[bool] = True) -> None:
         """Create batches (if necessary).
 
         Make dirs: `<output_data.filepath> / <split_name> / <data_source_name>`.
@@ -216,33 +216,38 @@ class ManagerLive(ManagerBase):
                     f"About to submit create_batches task for {data_source_name}, {split_name}"
                 )
 
-                # Sometimes when debuggin it is easy to use non async
-                # data_source.create_batches(**kwargs_for_create_batches)
+                if ~use_async:
+                    # Sometimes when debuggin it is easy to use non async
+                    data_source.create_batches(**kwargs_for_create_batches)
+                else:
 
-                async_result = pool.apply_async(
-                    data_source.create_batches,
-                    kwds=kwargs_for_create_batches,
-                    callback=partial(
-                        callback, data_source_name=data_source_name, split_name=split_name
-                    ),
-                    error_callback=partial(
-                        error_callback,
-                        data_source_name=data_source_name,
-                        split_name=split_name,
-                        an_error_has_occured=an_error_has_occured,
-                    ),
-                )
-                async_results_from_create_batches.append(async_result)
-
-            # Wait for all async_results to finish:
-            for async_result in async_results_from_create_batches:
-                async_result.wait()
-                if an_error_has_occured.is_set():
-                    # An error has occurred but, at this point in the code, we don't know which
-                    # worker process raised the exception.  But, with luck, the worker process
-                    # will have logged an informative exception via the _error_callback func.
-                    raise RuntimeError(
-                        f"A worker process raised an exception whilst working on {split_name}!"
+                    async_result = pool.apply_async(
+                        data_source.create_batches,
+                        kwds=kwargs_for_create_batches,
+                        callback=partial(
+                            callback, data_source_name=data_source_name, split_name=split_name
+                        ),
+                        error_callback=partial(
+                            error_callback,
+                            data_source_name=data_source_name,
+                            split_name=split_name,
+                            an_error_has_occured=an_error_has_occured,
+                        ),
                     )
+                    async_results_from_create_batches.append(async_result)
+
+                    # Wait for all async_results to finish:
+                    for async_result in async_results_from_create_batches:
+                        async_result.wait()
+                        if an_error_has_occured.is_set():
+                            # An error has occurred but, at this point in the code,
+                            # we don't know which worker process raised the exception.
+                            # But, with luck, the worker process
+                            # will have logged an informative exception via the
+                            # _error_callback func.
+                            raise RuntimeError(
+                                f"A worker process raised an exception whilst "
+                                f"working on {split_name}!"
+                            )
 
             logger.info(f"Finished creating batches for {split_name}!")
